@@ -1,7 +1,7 @@
 """http://fishbowl.pastiche.org/2004/01/19/persistent_login_cookie_best_practice/
 
 :organization: Logilab
-:copyright: 2009-2010 LOGILAB S.A. (Paris, FRANCE), license is LGPL v2.
+:copyright: 2009-2011 LOGILAB S.A. (Paris, FRANCE), license is LGPL v2.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 :license: GNU Lesser General Public License, v2.1 - http://www.gnu.org/licenses
 """
@@ -24,8 +24,8 @@ class AuthCookieAuthentifier(native.BaseAuthentifier):
         rset = session.execute(self.auth_rql, {'login': login,
                                                'magicnumber': magicnumber})
         if rset:
-            session.repo.glob_delete_entities(session, [rset[0][1]])
-            session.commit(reset_pool=False)
+            session.repo.glob_delete_entities(session, set((rset[0][1],)))
+            session.commit(free_cnxset=False)
             return rset[0][0]
         raise AuthenticationError('bad password')
 
