@@ -1,7 +1,7 @@
 """remberme cube hooks
 
 :organization: Logilab
-:copyright: 2009-2010 LOGILAB S.A. (Paris, FRANCE), license is LGPL v2.
+:copyright: 2009-2011 LOGILAB S.A. (Paris, FRANCE), license is LGPL v2.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 :license: GNU Lesser General Public License, v2.1 - http://www.gnu.org/licenses
 """
@@ -22,7 +22,8 @@ class ServerStartupHook(hook.Hook):
         def cleanup_auth_cookies(repo=self.repo):
             session = repo.internal_session()
             try:
-                session.execute('DELETE CWAuthCookie X WHERE X lifetime L, X creation_date > (NOW - L)')
+                session.execute('DELETE CWAuthCookie X WHERE X lifetime L, '
+                                'X creation_date < (NOW - L)')
                 session.commit()
             finally:
                 session.close()
